@@ -202,13 +202,9 @@ class KinesisStreamsToLambdaProps:
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
         """
         if isinstance(kinesis_stream_props, dict):
-            kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(
-                **kinesis_stream_props
-            )
+            kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **lambda_function_props
-            )
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         self._values = {}
         if event_source_props is not None:
             self._values["event_source_props"] = event_source_props
